<template>
  <div>
    <BasicTable @register="registerTable">
      <template #toolbar>
        <a-button color="primary" @click="addTool"> 添加 </a-button>
        <a-button ghost color="primary" @click="aoaToExcel"> 导出 </a-button>
        <a-button ghost color="primary" @click="ExcelToaoa"> 导入 </a-button>
      </template>
      <template #action="{ record }">
        <TableAction :actions="[
      {
        icon: 'clarity:note-edit-line',
        tooltip: '修改',
        onClick: handleEdit.bind(null, record),
      },
      {
        icon: 'ant-design:delete-outlined',
        tooltip: '删除',
        popConfirm: {
          title: '是否确认删除?',
          placement: 'left',
          confirm: handleDelete.bind(null, record),
        },
      },
    ]" />
      </template>
    </BasicTable>
    <Loading :loading="compState.loading" :tip="compState.tip" />
    <!-- <WmsItemDrawer @register="registerDrawer" @success="handleSuccess" /> -->
    <SmttableDrawer @register="registerDrawer" @success="handleSuccess" />
    <SmttableModal @register="registerSmttable" @success="handleSuccess" />
  </div>
</template>
<script lang="ts" setup>
import { reactive, unref } from 'vue';
import { aoaToSheetXlsx } from '/@/components/Excel';
import { BasicTable, useTable, TableAction } from '/@/components/Table';
import SmttableDrawer from './SmttableDrawer.vue';
import SmttableModal from './SmttableModal.vue';
import { useDrawer } from '/@/components/Drawer';
import { columns, searchFormSchema } from './smttbale.data';
import { getSmttableListByPage, DeleteSmttable } from '/@/api/tigerapi/mes/smt/smttable';
import { useGo } from '/@/hooks/web/usePage';
import { Loading } from '/@/components/Loading';
import { useMessage } from '/@/hooks/web/useMessage';
import { useI18n } from '/@/hooks/web/useI18n';
import { useModal } from '/@/components/Modal';

const { t } = useI18n();
const { createMessage } = useMessage();
const [registerDrawer, { openDrawer }] = useDrawer();
const go = useGo();

const compState = reactive({
  absolute: false,
  loading: false,
  tip: '加载中...',
});
const [registerSmttable, { openModal: openSmttableModal }] = useModal();
const [registerTable, { getForm, getPaginationRef, reload }] = useTable({
  title: '工单料站表',
  api: getSmttableListByPage,
  columns,
  formConfig: {
    labelWidth: 120,
    schemas: searchFormSchema,
  },
  actionColumn: {
    width: 120,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: 'right', //undefined,
  },
  ellipsis: true,
  useSearchForm: true,
  showTableSetting: false,
  bordered: true,
  showIndexColumn: false,
});
let arr: any[] = [];
//导出
function aoaToExcel() {
  const totals = getPaginationRef().total
  if (totals < 30000) {
    arr = [];
    compState.loading = true;
    const col = getForm().getFieldsValue()
    getSmttableListByPage(col).then((res) => {
      res.items.forEach(element => {

        arr.push({
          '关联工单号': element.WORK_ORDER,
          '产品编码': element.PROD_CODE,
          '物料编码': element.ITEM_CODE,
          '替代料': element.SUBITEM_CODE,
          '单位': element.UNIT,
          '单位用量': element.UNIT_QTY,
          '产线编码': element.LINE_CODE,
          '贴片机编码': element.SMT_CODE,
          '钢网编码': element.SMT_STENCIL,
          '站位号': element.SLOT_NO,
          '贴片位置': element.LOCATION,
          '飞达编码': element.FEEDER_CODE,
          '飞达类型': element.FEEDER_TYPE,
          '加工面': element.PCB_SURFACE,
          '上料顺序': element.LOAD_SEQ,
          '创建人': element.CREATE_USER,
          '创建时间': element.CREATE_TIME,
        });
      });
      const arrHeader = columns.map((column) => column.title);
      const arrData = arr.map((item) => {
        return Object.keys(item).map((key) => item[key]);
      });
      // 保证data顺序与header一致
      if (arr.length < 30000) {
        aoaToSheetXlsx({
          data: arrData,
          header: arrHeader,
          filename: '工单料站表信息.xlsx',
        });
      } else {
        createMessage.error(t('导出数据不能超过三万条，如需要更多的请联系管理员'));
      }

      compState.loading = false;

    })

  } else {
    createMessage.error(t('导出数据不能超过三万条，如需要更多的请联系管理员'));
  }


}
//导入
function ExcelToaoa() {
  openSmttableModal(true, {
    data: 'content',
    info: 'Info',
  });
}
//添加
function addTool() {
  openDrawer(true, {
    isUpdate: false,
  });
}
//编辑
function handleEdit(record: any) {
  openDrawer(true, {
    isUpdate: true,
    record
  });
}
function handleSuccess() {
  reload();
}
//删除
function handleDelete(record: any) {
  const apiAction = DeleteSmttable(record.ID);
  apiAction.then((action) => {
    if (action.IsSuccessed) {
      createMessage.success(t('已删除'));
      reload();
    } else {
      createMessage.success(t('删除操作失败'));
    }
  });
}
</script>
